@@ -53,7 +53,9 @@ class benedict(KeypathDict, IODict, ParseDict):
         keeping the pointer to the original dict.
         """
         if isinstance(value, dict) and not isinstance(value, benedict):
-            return benedict(value, keypath_separator=self._keypath_separator)
+            return benedict(value,
+                            keypath_separator=self._keypath_separator,
+                            check_keys=False)
         return value
 
     def clean(self, strings=True, collections=True):
@@ -268,3 +270,10 @@ class benedict(KeypathDict, IODict, ParseDict):
         Remove duplicated values from the current dict instance.
         """
         _unique(self)
+
+
+# fix benedict yaml representer - #43
+from yaml import SafeDumper
+from yaml.representer import SafeRepresenter
+
+SafeDumper.yaml_representers[benedict] = SafeRepresenter.represent_dict
